Revert of Fix a few bugs in the google3 sync scripts. (patchset #1 id:1 of https://codereview.chromium.org/1291343006/ )

Reason for revert:
MacMini buildbots were unable to apply the patch.
fatal: Could not parse object '18af0a0080cc2b2b3464292d35a0886cdade551f'.
http://build.chromium.org/p/client.skia/builders/Test-Mac10.9-Clang-MacMini6.2-CPU-AVX-x86_64-Release/builds/1580
http://build.chromium.org/p/client.skia/builders/Test-Mac10.9-Clang-MacMini6.2-CPU-AVX-x86_64-Debug/builds/1474
http://build.chromium.org/p/client.skia/builders/Test-Mac10.9-Clang-MacMini6.2-GPU-HD4000-x86_64-Release/builds/1566
http://build.chromium.org/p/client.skia/builders/Perf-Mac10.9-Clang-MacMini6.2-GPU-HD4000-x86_64-Release/builds/1480
http://build.chromium.org/p/client.skia/builders/Perf-Mac10.9-Clang-MacMini6.2-CPU-AVX-x86_64-Release/builds/1456
http://build.chromium.org/p/client.skia/builders/Test-Mac10.9-Clang-MacMini6.2-GPU-HD4000-x86_64-Debug/builds/1364

Original issue's description:
> Fix a few bugs in the google3 sync scripts.
>
> BUG=skia:
>
> Committed: https://skia.googlesource.com/skia/+/18af0a0080cc2b2b3464292d35a0886cdade551f

TBR=mtklein@google.com
NOPRESUBMIT=true
NOTREECHECKS=true
NOTRY=true
BUG=skia:

Review URL: https://codereview.chromium.org/1295213002
diff --git a/tools/sync_google3.sh b/tools/sync_google3.sh
index 57d6ac9..50ad61c 100755
--- a/tools/sync_google3.sh
+++ b/tools/sync_google3.sh
@@ -25,7 +25,7 @@
   GOOGLE3="/google/src/cloud/${USER}/${CLIENT_NAME}/google3"
 fi
 cd "${GOOGLE3}/third_party/skia/HEAD"
-${MY_DIR}/git_clone_to_google3.sh --skia_rev "${LKGR}"
+${MY_DIR}/git_clone_to_google3.sh --skia-rev "${LKGR}"
 
 # Update README.google.
 sed --in-place "s/^Version: .*/Version: ${LKGR}/" README.google
diff --git a/tools/git_clone_to_google3.sh b/tools/git_clone_to_google3.sh
index 38d79e3..1e2f34f 100755
--- a/tools/git_clone_to_google3.sh
+++ b/tools/git_clone_to_google3.sh
@@ -12,7 +12,6 @@
 
 source gbash.sh || exit
 DEFINE_string skia_rev "" "Git hash of Skia revision to clone, default LKGR."
-gbash::init_google "$@"
 
 set -x -e
 
@@ -49,8 +48,8 @@
   --include=/dm \
   --include=/gm \
   --include=/include \
-  --exclude=/src/animator \
   --include=/src \
+  --exclude=/src/animator \
   --include=/tests \
   --include=/third_party \
   --include=/tools \
@@ -81,17 +80,12 @@
 g4 revert README.google
 g4 revert BUILD
 
 # Use google3 version of OWNERS.
 find . \
-  -name OWNERS \
+  \( -name OWNERS -o -name README.google -o -name BUILD \) \
   -exec git update-index --skip-worktree \{\} \; \
   -execdir g4 revert \{\} \;
 
-# Tell git to ignore these files that have Windows line endings, because Piper
-# will always change them to Unix line endings.
-git update-index --skip-worktree make.bat
-git update-index --skip-worktree make.py
-
 # Tell git to ignore files left out of the rsync (i.e. "deleted" files).
 git status --porcelain | \
   grep -e "^ D" | \
@@ -81,17 +80,12 @@
 g4 revert BUILD
 
-# Use google3 version of OWNERS.
+# Use google3 version of OWNERS, README.google, and BUILD.
 find . \